@@ -61,12 +61,36 @@ class EventCategoryTitle(models.Model):
 
 class EventManager(models.Manager):
     """Custom manager for the ``Event`` model."""
-    def get_visible(self):
+    def get_archived(self, request):
+        language = getattr(request, 'LANGUAGE_CODE', None)
+
         qs = self.get_query_set()
-        qs = qs.filter(is_published=True)
+        qs = qs.filter(eventtitle__is_published=True).distinct()
         qs = qs.filter(
-            Q(start_date__gte=timezone.now()) |
-            Q(end_date__gte=timezone.now()))
+            Q(start_date__lt=timezone.now()) & (
+                Q(end_date__isnull=True) | Q(end_date__lt=timezone.now())))
+
+        if not language:
+            return qs
+        qs = qs.filter(
+            eventtitle__language=language,
+        )
+        return qs
+
+    def get_upcoming(self, request):
+        language = getattr(request, 'LANGUAGE_CODE', None)
+
+        qs = self.get_query_set()
+        qs = qs.filter(eventtitle__is_published=True).distinct()
+        qs = qs.filter(
+            Q(end_date__gte=timezone.now()) |
+            Q(start_date__gte=timezone.now()))
+
+        if not language:
+            return qs
+        qs = qs.filter(
+            eventtitle__language=language,
+        )
         return qs
 
 
@@ -77,8 +101,6 @@ class Event(SimpleTranslationMixin, models.Model):
     For translateable fields see ``EventTitle``.
 
     :start_date: The DateTime when this event starts.
-    :is_published: If ``True``, the event would be returned by the
-      ``get_events`` templatetag.
     :creation_date: The DateTime when this event was created.
     :user: The user who created this event.
 
@@ -148,11 +170,6 @@ class Event(SimpleTranslationMixin, models.Model):
         null=True, blank=True,
     )
 
-    is_published = models.BooleanField(
-        default=False,
-        verbose_name=_('Is published'),
-    )
-
     creation_date = models.DateTimeField(
         auto_now_add=True,
         verbose_name=('Creation date'),
@@ -195,7 +212,7 @@ class Event(SimpleTranslationMixin, models.Model):
             if trans.postal_code:
                 full_address += u'{0} '.format(trans.postal_code)
             full_address += u'{0}<br />'.format(trans.city)
-        full_address += u'{0}'.format(self.country.name.encode())
+        full_address += u'{0}'.format(unicode(self.country.name))
         return full_address
 
     def get_alternative_events(self):
@@ -207,7 +224,7 @@ class Event(SimpleTranslationMixin, models.Model):
         result = u''
         if trans.city:
             result += u'{0}, '.format(trans.city)
-        result += self.country.name.encode()
+        result += unicode(self.country.name)
         return result
 
     def get_number_of_days(self):
@@ -226,6 +243,17 @@ class EventTitle(models.Model):
     """
     Translateable fields of the ``Event`` model.
 
+    :title: Title off the event.
+    :venue_name: The venue, this event takes place.
+    :city: The city the event will be in.
+    :postal_code: The postal code of the city:
+    :address_1: The address of the event.
+    :address_2: An additional address of the event.
+    :room: The room this event will be in.
+    :description: A description of the event
+    :is_published: If ``True``, the event would be returned by the
+      ``get_events`` templatetag.
+
     """
     title = models.CharField(
         max_length=512,
@@ -273,6 +301,11 @@ class EventTitle(models.Model):
         blank=True,
     )
 
+    is_published = models.BooleanField(
+        default=False,
+        verbose_name=_('Is published'),
+    )
+
     # Needed by simple_translation
     event = models.ForeignKey(Event, verbose_name=_('Event'))
     language = models.CharField(max_length=5, verbose_name=('Language'))
